@@ -215,14 +215,7 @@ class CfnAssessmentTemplate(
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.List[str],
         assessment_template_name: typing.Optional[str] = None,
-        user_attributes_for_findings: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
-                ],
-            ]
-        ] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
 
@@ -344,12 +337,7 @@ class CfnAssessmentTemplate(
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -360,14 +348,7 @@ class CfnAssessmentTemplate(
     @user_attributes_for_findings.setter
     def user_attributes_for_findings(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]],
     ) -> None:
         jsii.set(self, "userAttributesForFindings", value)
 
@@ -391,14 +372,7 @@ class CfnAssessmentTemplateProps:
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.List[str],
         assessment_template_name: typing.Optional[str] = None,
-        user_attributes_for_findings: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
-                ],
-            ]
-        ] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
@@ -460,12 +434,7 @@ class CfnAssessmentTemplateProps:
     @builtins.property
     def user_attributes_for_findings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -504,10 +473,7 @@ class CfnResourceGroup(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        resource_group_tags: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-        ],
+        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
     ) -> None:
         """Create a new ``AWS::Inspector::ResourceGroup``.
 
@@ -563,10 +529,7 @@ class CfnResourceGroup(
     @jsii.member(jsii_name="resourceGroupTags")
     def resource_group_tags(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
@@ -577,10 +540,7 @@ class CfnResourceGroup(
     @resource_group_tags.setter
     def resource_group_tags(
         self,
-        value: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-        ],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
     ) -> None:
         jsii.set(self, "resourceGroupTags", value)
 
@@ -594,10 +554,7 @@ class CfnResourceGroupProps:
     def __init__(
         self,
         *,
-        resource_group_tags: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-        ],
+        resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]],
     ) -> None:
         """Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
@@ -613,10 +570,7 @@ class CfnResourceGroupProps:
     @builtins.property
     def resource_group_tags(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
